@@ -10,6 +10,7 @@ Created on Thu Dec 16 12:47:50 2021
 import os
 import tkinter as tk
 import tkinter.ttk as ttk
+from tkinter import PhotoImage
 
 from .src.classes.main_viewer import MainApplication
 
@@ -38,17 +39,19 @@ def topasgraphsim():
         ),
     )
     MainApplication(root)
+
     root.after(
         50,
-        root.iconbitmap(
-            str(
-                os.path.join(
+        root.iconphoto(
+            True,
+            PhotoImage(
+                file=os.path.join(
                     os.path.dirname(os.path.realpath(__file__)),
                     "src",
                     "resources",
-                    "icon.ico",
+                    "icon.png",
                 )
-            )
+            ),
         ),
     )
     root.mainloop()
